/**
  *  \file game/sweep.h
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_SWEEP_H
#define PCC_V2_GAME_SWEEP_H

#include "cpluslib/string.h"
#include "game/playerset.h"

/** Game directory manipulation utiltity.
    Provides functions to manipulate a game directory, and maintains a
    verbosity flag to control logging. */
class GGameDirManipulator {
 public:
    GGameDirManipulator();

    void setVerbose(bool flag);
    bool isVerbose() const;

    int getNumRemovedFiles() const;

    void removeGameFile(string_t name);

 private:
    bool opt_verbose;

    int num_removed_files;
};

/** "Sweep" processor. Interface for the back-end of a "Sweep" utility.
    "Sweep" (GSweepControl) will operate through this interface, allowing
    the user to hook own routines into it. A GUI version might want to
    display a list of the files to be erased first. */
class GSweepProcessor {
 public:
    virtual ~GSweepProcessor()
        { }
    virtual void removeFile(string_t name) = 0;
};

/** "Sweep" processor for immediate execution. This will immediately
    erase files requested to be erased by the "Sweep" utility. */
class GSweepRunProcessor : public GSweepProcessor,
                           public GGameDirManipulator
{
 public:
    GSweepRunProcessor();
    ~GSweepRunProcessor();

    void removeFile(string_t name);
};

/** "Sweep" control. This contains the main logic for the "Sweep"
    utility. "Sweep" erases player data from a game directory, but
    allows to specifically keep various items. */
class GSweepControl {
 public:
    GSweepControl();

    void scan();

    void processFiles(GSweepProcessor& processor);
    void processIndex();

    void setEraseDatabase(bool flag);

    void setPlayers(GPlayerSet set);
    GPlayerSet getPlayers() const;

    GPlayerSet getRemainingPlayers();

 private:
    bool opt_erase_db;
    bool have_scanned;

    GPlayerSet players;
    GPlayerSet remaining_players;

    void processPlayerFiles(GSweepProcessor& processor, int player);
};

#endif
