/**
  *  \file int/intglobal.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/intglobal.h"
#include "int/names.h"
#include "int/data.h"
#include "game/struct.h"
#include "cpluslib/assert.h"
#include "cpluslib/misc.h"

/** Names of all planet properties. */
IntVariableNames planet_property_names;

/** Names of all ship properties. */
IntVariableNames ship_property_names;

static IntDataSegment planet_properties[NUM_PLANETS];
static IntDataSegment ship_properties[NUM_SHIPS];

/** Initialize interpreter globals. Call this once per program invocation. */
void
initInterpreter()
{
    ship_property_names.add("COMMENT");
    planet_property_names.add("COMMENT");
}

/** Discard interpreter's game-specific data. Call this after closing
    down the game. */
void
clearInterpreterGameData()
{
    // Clear all properties
    for (unsigned i = 0; i < countof(planet_properties); ++i)
        planet_properties[i].clear();
    for (unsigned i = 0; i < countof(ship_properties); ++i)
        ship_properties[i].clear();
}

/** Get property data segment for a ship. */
IntDataSegment&
getShipProperties(int sid)
{
    ASSERT(sid > 0 && sid <= NUM_SHIPS);
    return ship_properties[sid-1];
}

/** Get property data segment for a planet. */
IntDataSegment&
getPlanetProperties(int pid)
{
    ASSERT(pid > 0 && pid <= NUM_PLANETS);
    return planet_properties[pid-1];
}
