/**
  *  \file util/conf-glob.cc
  *  \brief Global Configuration File
  *
  *  This module contains functions to load and save the global
  *  configuration file.
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "util/confpars.h"
#include "arch/platform.h"
#include "io/dirs.h"
#include "game/pref.h"
#include "io/streams.h"
#include "io/memstream.h"
#include "util/console.h"
#include "util/nls.h"
#include "cpluslib/format.h"

static string_t
getConfigFileName()
{
    return Directory::makeFileName(Platform::getUserSettingsDirectory(), "pcc2.ini");
}

void
loadConfig()
{
    Ptr<Stream> s = Stream::openFileNT(getConfigFileName(), Stream::C_READ);
    if (s) {
        ConfigFileParser cfp(getUserPreferences(), true);
        cfp.parseFile(*s);
    }
}

void
saveConfig()
{
    string_t name = getConfigFileName();

    // Update config file in memory
    MemoryStream ms;
    ConfigFileUpdater cfu(getUserPreferences(), ms);
    if (Ptr<Stream> s = Stream::openFileNT(name, Stream::C_READ)) {
        cfu.parseFile(*s);
    }
    cfu.finish();

    // Write it out
    Ptr<Stream> s = Stream::openFileNT(name, Stream::C_CREATE | Stream::C_WRITE);
    if (!s) {
        console.write(LOG_ERROR, format(_("Unable to create configuration file \"%s\""), name));
    } else {
        s->writeT(ms.getBuffer().ptr(), ms.getBuffer().getSize());
    }
}
